ThreadBorderRouterFault

Enum ThreadBorderRouterFault 

#[repr(u8)]
pub enum ThreadBorderRouterFault { Brgeneralfault = 0, Adjacentinfraiffault = 1, Servicesatcapacity = 2, Childrenatcapacity = 3, }

Variants



Brgeneralfault = 0

Indicates a generic unspecified fault related to the Border Router function.



Adjacentinfraiffault = 1

Indicates the adjacent infrastructure interface cannot be used for border routing.



Servicesatcapacity = 2

Indicates that a service or function associated with border routing has reached its maximum capacity (e.g., SRP server table full).



Childrenatcapacity = 3

Indicates that the Thread Border Router has reached its maximum supported number of direct MTD children.

Implementations

Source

impl ThreadBorderRouterFault

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value